Replace __bss_end__ with __bss_end

Note this is a tree-wide change affecting multiple architectures.

At present we use __bss_start, but mostly __bss_end__. This seems
inconsistent and in a number of places __bss_end is used instead.

Change to use __bss_end for the BSS end symbol throughout U-Boot. This
makes it possible to use the asm-generic/sections.h file on all
archs.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/arch/nios2/cpu/u-boot.lds b/arch/nios2/cpu/u-boot.lds
index d0eb80d..90a7795 100644
--- a/arch/nios2/cpu/u-boot.lds
+++ b/arch/nios2/cpu/u-boot.lds
@@ -101,7 +101,7 @@
 	  *(.scommon)
 	}
 	. = ALIGN(4);
-	__bss_end__ = .;
+	__bss_end = .;
 	PROVIDE (end = .);
 
 	/* DEBUG -- symbol table, string table, etc. etc.
diff --git a/arch/nios2/cpu/start.S b/arch/nios2/cpu/start.S
index 0f4ab28..1787b65 100644
--- a/arch/nios2/cpu/start.S
+++ b/arch/nios2/cpu/start.S
@@ -99,12 +99,12 @@
 3:
 
 	/* ZERO BSS/SBSS -- bss and sbss are assumed to be adjacent
 	 * and between __bss_start and __bss_end__.
 	 */
 	 movhi	r5, %hi(__bss_start)
 	 ori	r5, r5, %lo(__bss_start)
-	 movhi	r6, %hi(__bss_end__)
-	 ori	r6, r6, %lo(__bss_end__)
+	 movhi	r6, %hi(__bss_end)
+	 ori	r6, r6, %lo(__bss_end)
 	 beq	r5, r6, 5f
 
 4:	stwio	r0, 0(r5)
@@ -99,12 +99,12 @@
 
 	/* ZERO BSS/SBSS -- bss and sbss are assumed to be adjacent
-	 * and between __bss_start and __bss_end__.
+	 * and between __bss_start and __bss_end.
 	 */
 	 movhi	r5, %hi(__bss_start)